//
//  JSONSerializer.h
//  JSONSerializer
//
//  Created by Andreas Gerlach on 9/22/12.
//  Copyright (c) 2012 Appelgriebsch. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface JSONSerializer : NSObject

#pragma mark encoding

/*!
    encode the given object as JSON string

    @param theObject - an object that should be encoded

    @return the objects properties and values as JSON encoded string
 */
+(NSString *) encodeAsString:(id)theObject;

/*!
    encode the given object as JSON string and providing enhanced error information

    @param theObject - an object that should be encoded

    @param pError    - output parameter that will hold the error information - if any

    @return the objects properties and values as JSON encoded string
 */
+(NSString *) encodeAsString:(id)theObject error:(NSError **)pError;

/*!
    encode the given object as JSON data

    @param theObject - an object that should be encoded

    @return the objects properties and values as JSON encoded data
 */
+(NSData *) encodeAsData:(id)theObject;

/*!
    encode the given object as JSON data and providing enhanced error information

    @param theObject - an object that should be encoded

    @param pError    - output parameter that will hold the error information - if any

    @return the objects properties and values as JSON encoded data
 */
+(NSData *) encodeAsData:(id)theObject error:(NSError **)pError;

#pragma mark decoding

/*!
    decodes a JSON formatted string and returns the object (or dictionary of values)

    @param jsonData - the JSON formatted string to restore the data from

    @return an object that is encoded in the JSON data or a dictionary of key-values
 */
+(id) decodeString:(NSString *)jsonData;

/*!
    decodes a JSON formatted string and returns the object (or dictionary of values)

    @param jsonData - the JSON formatted string to restore the data from

    @param pError   - output parameter that will hold the error information - if any

    @return an object that is encoded in the JSON data or a dictionary of key-values
 */
+(id) decodeString:(NSString *)jsonData error:(NSError **)pError;

/*!
    decodes JSON formatted data and returns the object (or dictionary of values)

    @param jsonData - the JSON formatted data to restore

    @return an object that is encoded in the JSON data or a dictionary of key-values
 */
+(id) decodeData:(NSData *)jsonData;

/*!
    decodes JSON formatted data and returns the object (or dictionary of values)

    @param jsonData - the JSON formatted data to restore

    @param pError   - output parameter that will hold the error information - if any

    @return an object that is encoded in the JSON data or a dictionary of key-values
 */
+(id) decodeData:(NSData *)jsonData error:(NSError **)pError;

@end
