//
//  mongo_objc.h
//  mongo-objc
//
//  Created by Andreas Gerlach on 10/25/12.
//  Copyright (c) 2012 Appelgriebsch. All rights reserved.
//

#import <Foundation/Foundation.h>

#define MONGO_DEFAULT_PORT 27017

/*!
 objective-c wrapper to mongodb API
 
 @author Andreas Gerlach
 @copyright Appelgriebsch
 @charset utf-8
 @encoding utf-8
 @version 0.2
 
 */
@interface MongoDB : NSObject

/*!
 connect to a running mongodb
 
 @param host The name or IP address of the mongodb
 @param port The port the mongodb is listening on
 
 @return the initialized MongoDB object
 */
+ (id)connectTo:(NSString *)host onPort:(NSUInteger)port;

/*!
 tries to connect to a running mongodb within the given time interval
 
 @param host The name or IP address of the mongodb
 @param port The port the redis server is listening on
 @param interval The time interval to wait for the connection at maximum
 
 @return the initialized MongoDB object
 */
+ (id)connectTo:(NSString *)host onPort:(NSUInteger)port withTimeout:(NSTimeInterval)interval;

/*!
 disconnects from a mongodb, closing any open connection to it
 */
- (void)disconnect;

/*!
 flag denoting if a connection to a mongodb exists or not
 */
@property(nonatomic, readonly) BOOL isConnected;

/*!
    stores a complex document into the database
    
    @param document the document to store as single entity
    @param collection the collection to hold the document (<database>.<collection>)
    
    @return the unique ID to find the document later on
 */
- (NSString *)storeDocument:(id)document intoCollection:(NSString *)collection;

/*!
    retrieves a document from the database
 
    @param docID the unique ID of the document to get from the database
    @param collection the collection that holds the document (<database>.<collection>)
 
    @return the restored object or nil if not found
 */
- (id)retrieveObjectForDocument:(NSString *)docID fromCollection:(NSString *)collection;

@end
