//
//  main.m
//  redis-cli
//
//  Created by Andreas Gerlach on 7/9/12.
//  Copyright (c) 2012 Appelgriebsch. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <redis-objc/redis-objc.h>

int main(int argc, const char *argv[]) {

    @autoreleasepool {

        APGRedisServer *server = [APGRedisServer connectTo:@"127.0.0.1" onPort:REDIS_DEFAULT_PORT];

        if (server.connected) {

            NSLog(@"Connected to REDIS server");

            if (server.requiresAuthentication) {

                // TODO: prompt for password
                NSLog(@"Please enter the password of the server:");
            }


            NSLog(@"PING results in %@", [server ping]);
            NSLog(@"ECHO 'Hello World' results in %@", [server echo:@"Hello World"]);

            if ([server setDatabase:1])
                NSLog(@"SELECT database 1 succeeds");
            else
                NSLog(@"Error selecting database 1: %@", server.lastError);

            NSLog(@"DBSize results in %@", [server dbSize]);

            if ([server set:@"A B C" forKey:@"chars"]) {

                NSLog(@"Add Value 'ABC' for key 'chars' succeeds");
                NSLog(@"Get Value for key 'chars' results in %@", [server get:@"chars"]);
                NSLog(@"TTL for key 'chars' is %.2f secs.", [server retrieveTTL:@"chars"]);
            }
            else {

                NSLog(@"Add Value 'ABC' for key 'chars' failed with error: %@", server.lastError);
            }

            if ([server hasKey:@"chars"]) {

                [server append:@"DEF" toKey:@"chars"];

                NSLog(@"Get Value for key 'chars' results in %@", [server get:@"chars"]);

                [server deleteKey:@"chars"];
            }

            [server addCounter:@10 forKey:@"Jaegermeister"];

            NSLog(@"%@ Jaegermeister left...", [server getCounter:@"Jaegermeister"]);

            for (int i = 0; i < 10; ++i) {

                NSLog(@"%d: %@ Jaegermeister left...", i, [server decreaseCounter:@"Jaegermeister"]);
            }

            NSMutableArray *array = [[NSMutableArray alloc] initWithCapacity:10];

            for (int i = 0; i < 10; ++i) {

                [array addObject:[NSString stringWithFormat:@"%d", i]];
            }
        }
        else {

            NSLog(@"Error connecting to REDIS server: %@", server.lastError);
        }

        [server disconnect];
    }
    return 0;
}
