//
//  ReflectionHelper.h
//  ReflectionHelper
//
//  Created by Andreas Gerlach on 9/22/12.
//  Copyright (c) 2012 Appelgriebsch. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "NSObject+UniqueIdentifiable.h"

@interface ReflectionHelper : NSObject

/*!
    inspects an object and returns a dictionary
    with the property names and values

    @param theObject - the object that should be inspected

    @return a dictionary with all available properties and their values
 */
+ (NSDictionary *)inspectObject:(id)theObject;

/*!
    tries to recreate the object based on the value from the dictionary

    if no suitable class has been found it will return the original dictionary instead

    @param dictValue - the dictionary with the property values from the object

    @return the recreated object (is class is found) or the dictionary itself (if recreation not possible)
 */
+ (id)initObjectWithValues:(NSDictionary *)dictValues;

/*!
    tries to recreate the object of the given class based on the value from the dictionary

    @param ofClass   - the class that should be used for re-generating from

    @param dictValue - the dictionary with the property values from the object

    @return the recreated object (is class is found) or an empty instance of the class (if recreation not possible)

 */
+ (id)initObject:(Class)ofClass withValues:(NSDictionary *)dictValues;

@end
