//
//  riak_objc.h
//  riak-objc
//
//  Created by Andreas Gerlach on 10/27/12.
//  Copyright (c) 2012 Appelgriebsch. All rights reserved.
//

#import <Foundation/Foundation.h>

/*!
 objective-c wrapper to riak server API
 
 @author Andreas Gerlach
 @copyright Appelgriebsch
 @charset utf-8
 @encoding utf-8
 @version 0.2
 
 */

@interface RiakServer : NSObject

/*!
 connect to a running riak server
 
 @param host The name or IP address of the riak server
 @param port The port the riak is listening on
 
 @return the initialized RiakServer object
 */
+ (id)connectTo:(NSString *)host onPort:(NSUInteger)port;

/*!
 tries to connect to a running riak server within the given time interval
 
 @param host The name or IP address of the riak server
 @param port The port the riak server is listening on
 @param interval The time interval to wait for the connection at maximum
 
 @return the initialized RiakServer object
 */
+ (id)connectTo:(NSString *)host onPort:(NSUInteger)port withTimeout:(NSTimeInterval)interval;

/*!
    stores a document into the database
    
    @param document the document to put into the database
    @param bucket the bucket (namespace) that will hold the document
 
    @return the unique ID of the document in the database
 */
- (NSString *)storeDocument:(id)document inBucket:(NSString *)bucket;

/*!
    retrieves a document from the database
 
    @param key the unique ID of the document in the database
    @param bucket the bucket (namespace) that holds the document
 
    @return the restored object or nil if not found
 */
- (id)retrieveDocument:(NSString *)key fromBucket:(NSString *)bucket;

@end
