//
//  riak_objc.m
//  riak-objc
//
//  Created by Andreas Gerlach on 10/27/12.
//  Copyright (c) 2012 Appelgriebsch. All rights reserved.
//

#import "riak_objc.h"
#import <JSONSerializer/JSONSerializer.h>
#import <ReflectionHelper/ReflectionHelper.h>

@interface RiakServer()

@property (nonatomic, readonly) NSString *host;
@property (nonatomic, readonly) NSUInteger port;
@property (nonatomic, readonly) NSTimeInterval timeOut;

-(id) initWithHost:(NSString *)host port:(NSUInteger)port timeOut:(NSTimeInterval)timeOut;

@end

@implementation RiakServer

-(id) initWithHost:(NSString *)host port:(NSUInteger)port timeOut:(NSTimeInterval)timeOut {

    self = [super init];
    
    if (self) {
        
        _host = host;
        _port = port;
        _timeOut = timeOut;
    }
    
    return self;
}

+(id) connectTo:(NSString *)host onPort:(NSUInteger)port {
    
    return [RiakServer connectTo:host onPort:port withTimeout:-1];
}

+(id) connectTo:(NSString *)host onPort:(NSUInteger)port withTimeout:(NSTimeInterval)interval {
    
    RiakServer *server = [[RiakServer alloc] initWithHost:host port:port timeOut:interval];
    return server;
}

- (NSString *) storeDocument:(id)document inBucket:(NSString *)bucket {
    
    NSMutableURLRequest *urlRequest = nil;
    NSURL *url = [NSURL URLWithString:[NSString stringWithFormat:@"http://%@:%ld/riak/%@/%@",
                                       self.host, self.port, bucket, [document uniqueObjectID]]];
    
    if (self.timeOut > 0) {

        urlRequest = [NSMutableURLRequest requestWithURL:url cachePolicy:NSURLCacheStorageNotAllowed timeoutInterval:self.timeOut];
    }
    else {
        
        urlRequest = [NSMutableURLRequest requestWithURL:url];
    }

    NSData *jsonData = [JSONSerializer encodeAsData:document];

    [urlRequest setHTTPMethod:@"POST"];
    [urlRequest setHTTPBody:jsonData];
    [urlRequest addValue:@"application/json" forHTTPHeaderField:@"Content-Type"];

    NSError *error;

    [NSURLConnection sendSynchronousRequest:urlRequest returningResponse:nil error:&error];

    return (error == nil ? [document uniqueObjectID] : nil);
}

-(id) retrieveDocument:(NSString *)key fromBucket:(NSString *)bucket {
        
    NSMutableURLRequest *urlRequest = nil;
    NSURL *url = [NSURL URLWithString:[NSString stringWithFormat:@"http://%@:%ld/riak/%@/%@",
                                       self.host, self.port, bucket, key]];
    
    if (self.timeOut > 0) {
        
        urlRequest = [NSMutableURLRequest requestWithURL:url cachePolicy:NSURLCacheStorageNotAllowed timeoutInterval:self.timeOut];
    }
    else {
        
        urlRequest = [NSMutableURLRequest requestWithURL:url];
    }
    
    [urlRequest setHTTPMethod:@"GET"];
    [urlRequest addValue:@"application/json" forHTTPHeaderField:@"accepts"];
    
    NSError *error;

    NSData *data = [NSURLConnection sendSynchronousRequest:urlRequest returningResponse:nil error:&error];

    if (error) return nil;
    
    return [JSONSerializer decodeData:data];
}

@end
